@@ -1,5 +1,5 @@
 from beanstalk.tasks.action.server import (create_database, install_pip_requirements, compile_python_code,
-                                           create_venv, initialize_git, install_yum_packages)
+                                           create_venv, initialize_git, install_yum_packages, clean_old_items)
 
 
 def _(var):
@@ -22,7 +22,9 @@ RUN_LOCATION = '/var/run/beanstalk'
 # Hooked Actions
 #-----------------------------------------------------------------------------------------------------------------------
 PRE_SETUP_ACTIONS = []  # Only beanstalk settings
-POST_SETUP_ACTIONS = []  # Only beanstalk settings
+POST_SETUP_ACTIONS = [
+    clean_old_items,
+]  # Only beanstalk settings
 
 PRE_CREATE_ACTIONS = []  # project_name
 POST_CREATE_ACTIONS = [
