@@ -102,3 +102,14 @@ def install_yum_packages():
     yum_package_string = ' '.join(yum_packages)
     yum_command = 'sudo yum install {0}'.format(yum_package_string)
     local(yum_command)
+
+
+def clean_old_items():
+    print action_title('Clean old items')
+
+    def _exist_and_clean(path):
+        if os.path.exists(path):
+            local('rm -rf {0}'.format(path))
+
+    _exist_and_clean('/etc/sudoers.d/beanstalk_reload_httpd')
+    _exist_and_clean('/usr/sbin/httpd_reload')
