@@ -344,3 +344,19 @@ def deactivate(settings_path=None, **settings_patches):
     def core():
         run('bsjack server.deactivate_app:{project_name}'.format(project_name=project_name))
     execute(core)
+
+
+@beanstalk_task(beanstalk_role='app')
+def reload_remote(settings_path=None, **settings_patches):
+    """Deactivate apps in the remote
+    """
+    beanstalk_settings = load_role_settings(additional_settings_path=settings_path, **settings_patches)
+    set_verbose_level()
+    load_web_servers()
+
+    project_name = beanstalk_settings['PROJECT_NAME']
+
+    @roles('web_servers')
+    def core():
+        run('bsjack server.reload_app:{0}'.format(project_name))
+    execute(core)
