@@ -137,19 +137,12 @@ def setup(settings_path=None, **settings_patches):
         with open(global_uwsgi_ini_path, 'w') as f:
             f.write(global_uwsgi_ini_content)
 
-    # Apache command
-    httpd_cmd_path = '/usr/sbin/httpd_reload'
-    if not os.path.exists(httpd_cmd_path):
-        print section_title('Create apache-reload command')
-        httpd_cmd_source = os.path.join(BEANSTALK_ROOT_PATH, 'static/httpd_reload.sh')
-        local('/bin/cp -f %s %s' % (httpd_cmd_source, httpd_cmd_path))
-        local('chmod +x %s' % httpd_cmd_path)
-
-    # Give beanstalk permission
-    sudoer_file = '/etc/sudoers.d/beanstalk_reload_httpd'
+    # Give beanstalk permission for some commands
+    sudoer_file = '/etc/sudoers.d/beanstalk'
     if not os.path.exists(sudoer_file):
-        print section_title('Give beanstalk permission for apache-reload command')
-        local('echo "beanstalk ALL=(root) NOPASSWD: %s" > %s' % (httpd_cmd_path, sudoer_file))
+        print section_title('Give beanstalk permission for commands: yum-install and apache-reload')
+        sudoer_source = os.path.join(BEANSTALK_ROOT_PATH, 'static/beanstalk_sudoer')
+        local('/bin/cp -f %s %s' % (sudoer_source, sudoer_file))
         local('chmod 440 %s' % sudoer_file)
 
     # Make beanstalk access ssh
@@ -344,7 +337,7 @@ def commit_app(project_name, settings_path=None, **settings_patches):
     run_hooked_actions('PRE_COMMIT_ACTION')
 
     project_base = project_base_path(project_name)
-    with settings(lcd(project_base), hide('warnings'), warning=True):
+    with settings(lcd(project_base), hide('warnings'), warn_only=True):
         local('git add -A && git commit -m "state at %s"' % datetime.datetime.now().strftime('%s'))
 
     run_hooked_actions('POST_COMMIT_ACTION')
@@ -378,7 +371,7 @@ def activate_app(project_name, settings_path=None, **settings_patches):
         ]
         sed_command = '\\n'.join(commands)
         local(sed('$ a\\{command}'.format(command=sed_command), apache_conf_path()))
-        local('sudo /usr/sbin/httpd_reload')
+        local('sudo service httpd reload')
 
     run_hooked_actions('POST_ACTIVATE_ACTION')
 
@@ -394,7 +387,7 @@ def deactivate_app(project_name, settings_path=None, **settings_patches):
     load_role_settings(additional_settings_path=settings_path, **settings_patches)
     set_verbose_level()
     local(sed('/# {name}/,+7d'.format(name=project_name), apache_conf_path()))
-    local('sudo /usr/sbin/httpd_reload')
+    local('sudo service httpd reload')
 
     run_hooked_actions('POST_DEACTIVATE_ACTION')
 
